import React, { PropTypes } from 'react'
import Box from './Box'
import theme from './theme'

const getValue = (val) => Number.isInteger(val) ? val : ''

const parseShorthand = ({ dark, tint, white }) => {
  if (white) return { background: 'white' }
  if (tint) return { background: `tint${getValue(tint)}` }
  if (dark) return { background: 'dark' }
  return {}
}

const Pane = ({ dark, tint, white, ...props }) =>
  React.createElement(Box, { ...parseShorthand({ dark, tint, white }), ...props})

Pane.propTypes = {
  ...Box.propTypes,
  dark: PropTypes.bool,
  tint: PropTypes.oneOfType([
    PropTypes.bool,
    PropTypes.oneOf([1, 2])
  ]),
  white: PropTypes.bool
}

Pane.displayName = 'Pane'

Pane.defaultProps = {
  theme
}

export default Pane
